diff --git a/aptos/proof-server/src/bin/proof_server.rs b/aptos/proof-server/src/bin/proof_server.rs
index 059e97c1..efd506e4 100644
--- a/aptos/proof-server/src/bin/proof_server.rs
+++ b/aptos/proof-server/src/bin/proof_server.rs
@@ -422,9 +422,9 @@ async fn count_requests_middleware(
req: axum::http::Request
,
next: Next,
) -> Result {
- let is_health = req.uri().path() != "/health";
- // Check if the request is for the health endpoint.
- if is_health {
+ let is_ready = req.uri().path() != "/ready";
+ // Check if the request is for the ready endpoint.
+ if is_ready {
// Increment the active requests counter.
state.active_requests.fetch_add(1, Ordering::SeqCst);
}
@@ -432,8 +432,8 @@ async fn count_requests_middleware(
// Proceed with the request.
let response = next.run(req).await;
- // Decrement the active requests counter if not a health check.
- if is_health {
+ // Decrement the active requests counter if not a ready check.
+ if is_ready {
state.active_requests.fetch_sub(1, Ordering::SeqCst);
}
diff --git a/ethereum/light-client/src/bin/proof_server.rs b/ethereum/light-client/src/bin/proof_server.rs
index ac7640e9..f24808b3 100644
--- a/ethereum/light-client/src/bin/proof_server.rs
+++ b/ethereum/light-client/src/bin/proof_server.rs
@@ -308,10 +308,10 @@ async fn count_requests_middleware(
State(state): State,
req: axum::http::Request,
next: Next,
-) -> Result {
- let is_health = req.uri().path() != "/health";
- // Check if the request is for the health endpoint.
- if is_health {
+) -> std::result::Result {
+ let is_ready = req.uri().path() != "/ready";
+ // Check if the request is for the ready endpoint.
+ if is_ready {
// Increment the active requests counter.
state.active_requests.fetch_add(1, Ordering::SeqCst);
}
@@ -319,8 +319,8 @@ async fn count_requests_middleware(
// Proceed with the request.
let response = next.run(req).await;
- // Decrement the active requests counter if not a health check.
- if is_health {
+ // Decrement the active requests counter if not a ready check.
+ if is_ready {
state.active_requests.fetch_sub(1, Ordering::SeqCst);
}
diff --git a/kadena/light-client/src/bin/proof_server.rs b/kadena/light-client/src/bin/proof_server.rs
index 6c16b5eb..d4f3aada 100644
--- a/kadena/light-client/src/bin/proof_server.rs
+++ b/kadena/light-client/src/bin/proof_server.rs
@@ -116,10 +116,10 @@ async fn count_requests_middleware(
State(state): State,
req: axum::http::Request,
next: Next,
-) -> Result {
- let is_health = req.uri().path() != "/health";
- // Check if the request is for the health endpoint.
- if is_health {
+) -> std::result::Result {
+ let is_ready = req.uri().path() != "/ready";
+ // Check if the request is for the ready endpoint.
+ if is_ready {
// Increment the active requests counter.
state.active_requests.fetch_add(1, Ordering::SeqCst);
}
@@ -127,8 +127,8 @@ async fn count_requests_middleware(
// Proceed with the request.
let response = next.run(req).await;
- // Decrement the active requests counter if not a health check.
- if is_health {
+ // Decrement the active requests counter if not a ready check.
+ if is_ready {
state.active_requests.fetch_sub(1, Ordering::SeqCst);
}